==> s3mock-2.17.0-sources.jar: com/adobe/testing/s3mock/dto/BucketLifecycleConfiguration.java <==
/*
 *  Copyright 2017-2022 Adobe.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *          http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package com.adobe.testing.s3mock.dto;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonRootName;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlElementWrapper;
import java.util.List;
import java.util.Objects;

/**
 * <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_BucketLifecycleConfiguration.html">API Reference</a>.
 * <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_LifecycleConfiguration.html">API Reference</a>.
 */
@JsonRootName("LifecycleConfiguration")
@JsonInclude(JsonInclude.Include.NON_EMPTY)
public class BucketLifecycleConfiguration {

  @JsonProperty("Rule")
  @JacksonXmlElementWrapper(useWrapping = false)
  List<LifecycleRule> rules;

  public BucketLifecycleConfiguration() {
  }

  public BucketLifecycleConfiguration(List<LifecycleRule> rules) {
    this.rules = rules;
  }

  public List<LifecycleRule> getRules() {
    return rules;
  }

  public void setRules(List<LifecycleRule> rules) {
    this.rules = rules;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BucketLifecycleConfiguration that = (BucketLifecycleConfiguration) o;
    return Objects.equals(rules, that.rules);
  }

  @Override
  public int hashCode() {
    return Objects.hash(rules);
  }
}

==> s3mock-3.10.0-sources.jar: com/adobe/testing/s3mock/dto/BucketLifecycleConfiguration.java <==
/*
 *  Copyright 2017-2024 Adobe.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *          http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package com.adobe.testing.s3mock.dto;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonRootName;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlElementWrapper;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import java.util.List;

/**
 * <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_BucketLifecycleConfiguration.html">API Reference</a>.
 * <a href="https://docs.aws.amazon.com/AmazonS3/latest/API/API_LifecycleConfiguration.html">API Reference</a>.
 */
@JsonRootName("LifecycleConfiguration")
public record BucketLifecycleConfiguration(
    @JsonProperty("Rule")
    @JacksonXmlElementWrapper(useWrapping = false)
    List<LifecycleRule> rules,
    //workaround for adding xmlns attribute to root element only.
    @JacksonXmlProperty(isAttribute = true, localName = "xmlns")
    String xmlns
) {
  public BucketLifecycleConfiguration {
    if (xmlns == null) {
      xmlns = "http://s3.amazonaws.com/doc/2006-03-01/";
    }
  }

  public BucketLifecycleConfiguration(List<LifecycleRule> rules) {
    this(rules, null);
  }
}
